/**
 * 
 */
package net.bigeon.gclc.swt;

import java.io.BufferedReader;

import org.eclipse.swt.widgets.Label;

/** The manager for the console prompt updates.
 * 
 * @author Emmanuel Bigeon */
public final class ConsolePromptManager {

    /** The label to set the prompts at. */
    private final Label label;

    /** The current prompt reading runnable. */
    private PromptReadingRunnable promptRead;

    /** Create the manager.
     * 
     * @param label the label to update with prompts */
    public ConsolePromptManager(final Label label) {
        super();
        this.label = label;
    }

    /** Set the prompt.
     * <p>
     * This method sets the prompt on the label as requested, without changing the
     * actual prompt of the console input.
     * 
     * @param string the text */
    public void setPrompt(final String string) {
        label.setText(string);
    }

    /** Set the input to control.
     * 
     * @param promptStream the input */
    public void setStream(final BufferedReader promptStream) {
        if (promptRead != null) {
            if (promptRead.getReader() == promptStream) {
                return;
            }
            promptRead.setRunning(false);
        }
        if (promptStream == null) {
            promptRead = null;
            return;
        }
        promptRead = new PromptReadingRunnable(promptStream, label);
        final Thread th = new Thread(promptRead, "Prompt To Label");
        th.start();
    }
}
