/*
 * GCLC swt, provide a swt window for console applications
 * Copyright (C) 2015-2017 E. Bigeon
 * mailto:emmanuel@bigeon.fr
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc-swt:net.bigeon.gclc.swt.SWTConsole.java
 * Created on: Apr 18, 2015
 */
package net.bigeon.gclc.swt;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;

import net.bigeon.gclc.ConsoleApplication;
import net.bigeon.gclc.utils.PipedConsoleInput;
import net.bigeon.gclc.utils.PipedConsoleOutput;

/** A SWT component to connect to gclc {@link ConsoleApplication}.
 *
 * @author Emmanuel Bigeon */
public final class SWTConsoleView extends Composite {
    /** The input manager. */
    private final ConsoleInputManager  inManager;
    /** The output manager. */
    private final ConsoleOutputManager outManager;

    /** Create the composite.
     *
     * @param parent the prent composite
     * @param style the composite style */
    public SWTConsoleView(final Composite parent, final int style) {
        super(parent, style);

        setLayout(new GridLayout(1, false));

        final Text consoleOutput = new Text(this,
                SWT.BORDER | SWT.READ_ONLY | SWT.WRAP | SWT.V_SCROLL | SWT.MULTI);
        consoleOutput.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
        consoleOutput.setRedraw(true);
        outManager = new ConsoleOutputManager(consoleOutput);

        final Text consoleInput = new Text(this, SWT.BORDER);
        consoleInput.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
        inManager = new ConsoleInputManager(consoleInput);
        consoleInput.addKeyListener(new HistoryTextKeyListener(inManager));
    }

    /* (non-Javadoc)
     * @see org.eclipse.swt.widgets.Composite#setFocus() */
    @Override
    public boolean setFocus() {
        return inManager.getText().setFocus();
    }

    /** Set the input and output.
     *
     * @param manager the output to set
     * @param input the input */
    public void setManager(final PipedConsoleOutput manager,
            final PipedConsoleInput input) {
        outManager.setManager(manager);
        inManager.setManager(input);
    }

    /** Get the manager of console input.
     * 
     * @return the input manager */
    public ConsoleInputManager getInputManager() {
        return inManager;
    }

    /** Get the manager of console output.
     * 
     * @return the output manager */
    public ConsoleOutputManager getOutputManager() {
        return outManager;
    }
}
